@@ -12,7 +12,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(list_org_todos);
 
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 our %SPEC;
 
@@ -42,7 +42,7 @@ App::ListOrgTodos - List todo items in Org files
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -54,9 +54,16 @@ version 0.14
 
 None are exported, but they are exportable.
 
+=head1 DESCRIPTION
+
+
+This module has L<Rinci> metadata.
+
 =head1 FUNCTIONS
 
 
+None are exported by default, but they are exportable.
+
 =head2 list_org_todos(%args) -> [status, msg, result, meta]
 
 List all todo items in all Org files.
@@ -65,7 +72,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<cache_dir>* => I<str>
+=item * B<cache_dir> => I<str>
 
 Cache Org parse result.
 
@@ -90,7 +97,7 @@ active, then it will also pass this filter irregardless. Example, if today is
 pass the filter but  will (warning period 14 days is
 already active by that time).
 
-=item * B<files>* => I<array>
+=item * B<files> => I<array>
 
 =item * B<from_level> => I<int> (default: 1)
 
@@ -120,9 +127,9 @@ Filter todo items that have this priority.
 
 Specify sorting.
 
-If string, must be one of 'dueB<date', '-due>date' (descending).
+If string, must be one of 'dueI<date', '-due>date' (descending).
 
-If code, sorting code will get [REC, DUEB<DATE, HL] as the items to compare,
+If code, sorting code will get [REC, DUEI<DATE, HL] as the items to compare,
 where REC is the final record that will be returned as final result (can be a
 string or a hash, if 'detail' is enabled), DUE>DATE is the DateTime object (if
 any), and HL is the Org::Headline object.
